@@ -42,8 +42,8 @@ from skimage.morphology import skeletonize
 from stardist.models.base import StarDistBase
 import math
 import pandas as pd
-
-
+import napari
+import glob
 
 class SegCorrect(object):
 
